@@ -1,7 +1,7 @@
 package Perinci::CmdLine::POD;
 
-our $DATE = '2017-02-24'; # DATE
-our $VERSION = '0.011'; # VERSION
+our $DATE = '2017-02-27'; # DATE
+our $VERSION = '0.012'; # VERSION
 
 use 5.010001;
 use strict;
@@ -482,7 +482,8 @@ sub gen_pod_for_pericmd_script {
                         my @lines = split /^/, $fres;
                         if (@lines > $max_lines) {
                             my $n = int($max_lines/2);
-                            splice @lines, $n, (@lines - $max_lines + 1), "...\n";
+                            my $num_remove = @lines - $max_lines + 1;
+                            splice @lines, $n, $num_remove, "... ".($num_remove > 1 ? "$num_remove more lines" : "1 more line")." ...\n";
                             $fres = join("", @lines);
                         }
                     }
@@ -974,7 +975,7 @@ Perinci::CmdLine::POD - Generate POD for Perinci::CmdLine-based CLI script
 
 =head1 VERSION
 
-This document describes version 0.011 of Perinci::CmdLine::POD (from Perl distribution Perinci-CmdLine-POD), released on 2017-02-24.
+This document describes version 0.012 of Perinci::CmdLine::POD (from Perl distribution Perinci-CmdLine-POD), released on 2017-02-27.
 
 =head1 SYNOPSIS
 
